==> angular-ui-mask-1.6.1.jar: META-INF/resources/webjars/angular-ui-mask/1.6.1/karma.conf.js <==
// Karma configuration
// Generated on Fri Sep 27 2013 23:41:22 GMT+0200 (W. Europe Daylight Time)

module.exports = function(config) {
  config.set({

    // frameworks to use
    frameworks: ['jasmine'],


    // list of files / patterns to load in the browser
    files: [
      'bower_components/angular/angular.js',
      'bower_components/angular-mocks/angular-mocks.js',
      'dist/*.min.js',
      'test/*Spec.js'
    ],


    // list of files to exclude
    exclude: [

    ],


    // test results reporter to use
    // possible values: 'dots', 'progress', 'junit', 'growl', 'coverage'
    reporters: ['progress'],


    // web server port
    port: 9876,


    // enable / disable colors in the output (reporters and logs)
    colors: true,


    // level of logging
    // possible values: config.LOG_DISABLE || config.LOG_ERROR || config.LOG_WARN || config.LOG_INFO || config.LOG_DEBUG
    logLevel: config.LOG_INFO,


    // enable / disable watching file and executing tests whenever any file changes
    autoWatch: true,


    // Start these browsers, currently available:
    // - Chrome
    // - ChromeCanary
    // - Firefox
    // - Opera
    // - Safari (only Mac)
    // - PhantomJS
    // - IE (only Windows)
    browsers: ['Firefox'],


    // If browser does not capture in given timeout [ms], kill it
    captureTimeout: 60000,


    // Continuous Integration mode
    // if true, it capture browsers, run tests and exit
    singleRun: false
  });

  // Sauce Specific configuration for CI
  if (process.env.SAUCE_USERNAME && process.env.SAUCE_ACCESS_KEY) {
    config.reporters.push('saucelabs');

    config.set({
      sauceLabs: {
        testName: 'UI Mask CI'
      },
      captureTimeout:  120000,
      singleRun: true
    });
  }
};

==> angular-ui-mask-1.8.7.jar: META-INF/resources/webjars/angular-ui-mask/1.8.7/karma.conf.js <==
// Karma configuration
// Generated on Fri Sep 27 2013 23:41:22 GMT+0200 (W. Europe Daylight Time)

module.exports = function(config) {
  config.set({

    // frameworks to use
    frameworks: ['jasmine'],


    // list of files / patterns to load in the browser
    files: [
      'bower_components/angular/angular.js',
      'bower_components/angular-mocks/angular-mocks.js',
      'dist/*.min.js',
      'test/*Spec.js'
    ],


    // list of files to exclude
    exclude: [

    ],


    // test results reporter to use
    // possible values: 'dots', 'progress', 'junit', 'growl', 'coverage'
    reporters: ['progress','saucelabs'],


    // web server port
    port: 9876,


    // enable / disable colors in the output (reporters and logs)
    colors: true,


    // level of logging
    // possible values: config.LOG_DISABLE || config.LOG_ERROR || config.LOG_WARN || config.LOG_INFO || config.LOG_DEBUG
    logLevel: config.LOG_INFO,


    // enable / disable watching file and executing tests whenever any file changes
    autoWatch: true,


    // Start these browsers, currently available:
    // - Chrome
    // - ChromeCanary
    // - Firefox
    // - Opera
    // - Safari (only Mac)
    // - PhantomJS
    // - IE (only Windows)
    browsers: ['Firefox'],


    // If browser does not capture in given timeout [ms], kill it
    captureTimeout: 60000,


    // Continuous Integration mode
    // if true, it capture browsers, run tests and exit
    singleRun: false
  });

  // Sauce Specific configuration for CI
  if (process.env.SAUCE_USERNAME && process.env.SAUCE_ACCESS_KEY) {
    config.reporters.push('saucelabs');

    config.set({
      sauceLabs: {
        testName: 'UI Mask CI',
        tunnelIdentifier: process.env.TRAVIS_JOB_NUMBER,
        startConnect: false
      },
      captureTimeout:  120000,
      singleRun: true
    });
  }
};
